%% Representación gráfica de la Función de Ambigüedad

% La señal s tiene originalmente Nor muestras de duración pero un total de
% N muestras para los cálculos

% La FA es simétrica con x(tau,f) = x(-tau,-f). No hay que calcular ambos
% lados de f, pero si de t.

t = (1 : 1 : N);
t = [-fliplr(t) 0 t];

% Obtengamos un vector de frecuencias. Basta con tener las positivas por
% ser simétrica

f  = linspace(0 , flimite*N/dur_senal, num_f );

% Calculamos...
val=get(handles.predefinidas,'Value');
str=get(handles.predefinidas,'String');

switch str{val}
    
    case 'L1C' 
       mapacolor='default';
    case 'L2C'   
       mapacolor='jet';
    case 'L5' % Típico codificado en fase
       mapacolor='summer';
end

for fd = 1 : length(f)
    for tiempo = 1 : length(t)  % recorremos todo el vector el tiempo
                                % con todos los valores posibles de tau
        tau = t(tiempo);        % tau es redundante pero sirve para fijar
                                % el concepto mentalmente
        
        z = 0;                  % Ponemos a cero la suma
                     
        for n = 1 : length(s)   % Hacemos la suma para todas las muestras de s
                                % Solo sumamos cuando el indice de la suma está
                                % en el rango 1 - N
                                
            if (n + tau) <= length(s) && (n + tau) > 0 
                
                e = exp(1i*2*pi * (f(fd)*dur_senal/N) * n );
                z= z + ( s(n) * conj(s(n + tau) * e));
               
            end
        end
    
        x(tiempo, fd) = abs(z); % OJO: las filas del tiempo van desde -tau hasta +tau
                                % las columnas de las frecuencias desde 0 a
                                % flimite.
     end
end

% En este punto tenemos x(tiempo, frecuencia) con el tiempo cubriendo
% [-N,N] pero esto hay que confinarlo al rango [-T,T]

tau = (-1: 1/N : 1)*dur_senal;

% Normalizamos la FA y el corte
x=x/max(max(x));

corte_tau_cero = x(N+1,:); % Fila intermedia de tiempos
corte_tau_cero=corte_tau_cero/max(max(corte_tau_cero));

if neg == 1     % Pintamos también las frecuencias negativas 
                % Recordamos que X(-tau, -f) = X(tau, f) y las disposcición
                % de X es filas (tiempo) x columnas (fd)
                % Concatenamos verticalmente las rotaciones del segundo y
                % tercer cuadrante y horizontalmente con X
                % También creamos un vector de frecuencias extendido
    
    x = [ [rot90(x(N+1:end , 2:end),2) ; rot90(x(1:N , 2:end),2)] x];
    f = [ fliplr([f(2 : end)]*-1) f];
    corte_tau_cero = [ fliplr([corte_tau_cero(2 : end)]) corte_tau_cero ];
    autocorrelacion = x(:, ceil(length(f)/2)); % Columna  correspondiente a fd = 0
else
    x2 = [ [rot90(x(N+1:end , 2:end),2) ; rot90(x(1:N , 2:end),2)] x];
    f2 = [ fliplr([f(2 : end)]*-1) f];
    autocorrelacion = x2(:, ceil(length(f2)/2)); % Columna  correspondiente a fd = 0
end

tau =fliplr(tau);
h1  =findobj('Tag', 'grafica');

if tresd == 1   % Queremos la representación en 3D
    
    mesh(tau, f, x')
    colormap(mapacolor)
    xlim([min(tau) max(tau)])
    ylim([f(1) f(length(f))])
    hold on

    view(145,30)

    plot3( ones(length(f))*min(tau), f , corte_tau_cero,  'LineWidth', 1, 'Color', [0 0 1] ) 
    
    if neg == 1 
      plot3(tau, ones(length(tau))*(-f(end)),  autocorrelacion,  'LineWidth', 1, 'Color', [1 0 0] ) 
    end

else            % Queremos la representación plana
    contour(tau, f, x')
    hold on   
end
    grid on
    xlabel(['Retardo en ' '\mu' 's'])
    ylabel('Frecuencia doppler en MHz')
    zlabel('|X(tau, fd)| normalizada')
    hold off
    
    